==> mercury_editor-2.1.2.tar.gz: mercury_editor/src/Form/DialogSettingsForm.php <==
<?php

namespace Drupal\mercury_editor\Form;

use Drupal\Component\Serialization\Yaml;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Mercury Editor Edit Tray settings form.
 */
class DialogSettingsForm extends ConfigFormBase {

  /**
   * The YAML parser service.
   *
   * @var \Drupal\Component\Serialization\Yaml
   */
  protected $yamlParser;

  /**
   * SettingsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Serialization\Yaml $yaml_parser
   *   The YAML parser service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    Yaml $yaml_parser
  ) {
    parent::__construct($config_factory);
    $this->yamlParser = $yaml_parser;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('serialization.yaml')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mercury_editor_dialog_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'mercury_editor.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('mercury_editor.settings');
    $settings_obj = $config->get('dialog_settings');
    $form['dialog_settings'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Dialog settings'),
      '#description' => $this->t('Enter the settings for the dialog in YAML format.'),
      '#default_value' => $this->yamlParser->encode($settings_obj),
    ];
    if (class_exists('Drupal\codemirror_editor\Element\CodeMirror')) {
      $form['dialog_settings']['#type'] = 'codemirror';
      $form['dialog_settings']['#codemirror'] = [
        'mode' => 'yaml',
        'lineNumbers' => TRUE,
        'lineWrapping' => TRUE,
        'indentUnit' => 2,
        'indentWithTabs' => FALSE,
        'matchBrackets' => TRUE,
        'autoCloseBrackets' => TRUE,
        'autoCloseTags' => TRUE,
        'styleActiveLine' => TRUE,
        'continueComments' => TRUE,
        'toolbar' => FALSE,
        'extraKeys' => [
          'Ctrl-Space' => 'autocomplete',
        ],
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('mercury_editor.settings');
    $settings_yml_string = $form_state->getValue('dialog_settings');
    $config->set('dialog_settings', $this->yamlParser->decode($settings_yml_string));
    $config->save();
    // Confirmation on form submission.
    $this->messenger()->addMessage($this->t('Mercury Editor dialog settings have been saved.'));
  }

}

==> mercury_editor-2.2.0.tar.gz: mercury_editor/src/Form/DialogSettingsForm.php <==
<?php

namespace Drupal\mercury_editor\Form;

use Drupal\Component\Serialization\Yaml;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Mercury Editor Edit Tray settings form.
 */
class DialogSettingsForm extends ConfigFormBase {

  /**
   * The YAML parser service.
   *
   * @var \Drupal\Component\Serialization\Yaml
   */
  protected $yamlParser;

  /**
   * Default values for dialog settings.
   */
  const DEFAULT_TRAY_WIDTH = 400;
  const DEFAULT_TRAY_HEIGHT = 400;

  /**
   * SettingsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config service.
   * @param \Drupal\Core\Serialization\Yaml $yaml_parser
   *   The YAML parser service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    TypedConfigManagerInterface $typedConfigManager,
    Yaml $yaml_parser,
  ) {
    parent::__construct(
      $config_factory,
      $typedConfigManager
    );
    $this->yamlParser = $yaml_parser;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('serialization.yaml')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mercury_editor_dialog_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'mercury_editor.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('mercury_editor.settings');
    $settings_obj = $config->get('dialog_settings');
    $form['dialog_settings'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Modal dialog settings'),
      '#description' => $this->t('Enter the settings for the modal dialog in YAML format.'),
      '#default_value' => $this->yamlParser->encode($settings_obj),
    ];
    $form['dialog_tray_width'] = [
      '#type' => 'number',
      '#title' => $this->t('Dialog tray width'),
      '#required' => TRUE,
      '#min' => 0,
      '#description' => $this->t('Enter the width of the dialog tray in pixels.'),
      '#default_value' => $config->get('dialog_tray_width') ?? self::DEFAULT_TRAY_WIDTH,
    ];
    if (class_exists('Drupal\codemirror_editor\Element\CodeMirror')) {
      $form['dialog_settings']['#type'] = 'codemirror';
      $form['dialog_settings']['#codemirror'] = [
        'mode' => 'yaml',
        'lineNumbers' => TRUE,
        'lineWrapping' => TRUE,
        'indentUnit' => 2,
        'indentWithTabs' => FALSE,
        'matchBrackets' => TRUE,
        'autoCloseBrackets' => TRUE,
        'autoCloseTags' => TRUE,
        'styleActiveLine' => TRUE,
        'continueComments' => TRUE,
        'toolbar' => FALSE,
        'extraKeys' => [
          'Ctrl-Space' => 'autocomplete',
        ],
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('mercury_editor.settings');
    $settings_yml_string = $form_state->getValue('dialog_settings');
    $config->set('dialog_settings', $this->yamlParser->decode($settings_yml_string));
    $config->set('dialog_tray_width', $form_state->getValue('dialog_tray_width'));
    $config->save();
    // Confirmation on form submission.
    $this->messenger()->addMessage($this->t('Mercury Editor dialog settings have been saved.'));
  }

}
